@@ -6,7 +6,7 @@ use warnings;
 
 use English qw{ -no_match_vars };
 
-use PPI::Document;
+use PPI::Document 1.281;
 use PPIx::QuoteLike 0.011;
 use PPIx::QuoteLike::Constant 0.011 qw{
     LOCATION_LINE
@@ -25,7 +25,7 @@ use Perl::Critic::Utils qw< :booleans :characters hashify :severities >;
 
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '0.114_01';
+our $VERSION = '0.114_02';
 
 Readonly::Scalar my $DEREF => q/->/;
 
@@ -1622,7 +1622,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2012-2022, 2024 Thomas R. Wyant, III
+Copyright (C) 2012-2022, 2024-2025 Thomas R. Wyant, III
 
 =head1 LICENSE
 
